@@ -33,16 +33,14 @@ extern "C" {
 #include "gmime-param.h"
 #include "gmime-content-type.h"
 
-enum _GMimePartEncodingType {
+typedef enum {
         GMIME_PART_ENCODING_DEFAULT,
         GMIME_PART_ENCODING_7BIT,
         GMIME_PART_ENCODING_8BIT,
         GMIME_PART_ENCODING_BASE64,
         GMIME_PART_ENCODING_QUOTEDPRINTABLE,
         GMIME_PART_NUM_ENCODINGS
-};
-
-typedef enum _GMimePartEncodingType GMimePartEncodingType;
+} GMimePartEncodingType;
 
 typedef struct _GMimePartDispositionParam GMimePartDispositionParam;
 
@@ -55,11 +53,13 @@ struct _GMimePartDisposition {
 typedef struct _GMimePartDisposition GMimePartDisposition;
 
 struct _GMimePart {
-	gchar *description;
-	gchar *content_id;
 	GMimeContentType *mime_type;
 	GMimePartEncodingType encoding;
 	GMimePartDisposition *disposition;
+	gchar *description;
+	gchar *content_id;
+	gchar *content_md5;
+	gchar *content_location;
 	
 	GByteArray *content;
 	
@@ -84,6 +84,13 @@ const gchar *g_mime_part_get_content_description (const GMimePart *mime_part);
 void g_mime_part_set_content_id (GMimePart *mime_part, const gchar *content_id);
 const gchar *g_mime_part_get_content_id (GMimePart *mime_part);
 
+void g_mime_part_set_content_md5 (GMimePart *mime_part, const gchar *content_md5);
+gboolean g_mime_part_verify_content_md5 (GMimePart *mime_part);
+const gchar *g_mime_part_get_content_md5 (GMimePart *mime_part);
+
+void g_mime_part_set_content_location (GMimePart *mime_part, const gchar *content_location);
+const gchar *g_mime_part_get_content_location (GMimePart *mime_part);
+
 void g_mime_part_set_content_type (GMimePart *mime_part, GMimeContentType *mime_type);
 const GMimeContentType *g_mime_part_get_content_type (GMimePart *mime_part);
 
@@ -104,8 +111,8 @@ const gchar *g_mime_part_get_filename (GMimePart *mime_part);
 void g_mime_part_set_boundary (GMimePart *mime_part, const gchar *boundary);
 const gchar *g_mime_part_get_boundary (GMimePart *mime_part);
 
-void g_mime_part_set_content (GMimePart *mime_part, const char *content, guint len);
-void g_mime_part_set_pre_encoded_content (GMimePart *mime_part, const char *content,
+void g_mime_part_set_content (GMimePart *mime_part, const gchar *content, guint len);
+void g_mime_part_set_pre_encoded_content (GMimePart *mime_part, const gchar *content,
 					  guint len, GMimePartEncodingType encoding);
 const gchar *g_mime_part_get_content (const GMimePart *mime_part, guint *len);
 
